import React, { Component, Fragment } from "react";
import { withTheme, withStyles } from "@material-ui/core/styles";
import {
  IconButton,
  Grid,
  Paper,
  Select,
  FormControl,
  InputLabel,
  MenuItem,
  Typography,
  Divider,
  TextField,
  FormControlLabel,
  Checkbox
} from "@material-ui/core";
import AddIcon from "@material-ui/icons/Add";
import DeleteIcon from "@material-ui/icons/Delete";
import { Form, Table } from "@openimis/fe-core";

const styles = theme => ({
  paper: theme.paper.paper,
  paperHeader: theme.paper.header,
  paperHeaderTitle: theme.paper.title,
  paperHeaderAction: theme.paper.action,
  item: theme.paper.item,
  tableTitle: theme.table.title,
  tableHeaderAction: theme.table.headerAction,
  label: {
    color: theme.palette.primary.main
  },
  photo: {
    height: "100%"
  },
  left: {
    textAlign: "left"
  },
  right: {
    textAlign: "right"
  },
  center: {
    textAlign: "center"
  }
});

const regions = [
  { value: "r1", label: "R1 Ultha" },
  { value: "r2", label: "R2 Tahida" }
];

const districts = [
  { value: "r1d1", label: "R1D1 Rapta" },
  { value: "r1d2", label: "R1D2 Jambero" },
  { value: "r1d3", label: "R1D3 Uptol" }
];

const municipalities = [
  { value: "r1d1m1", label: "R1D1M1 Achi" },
  { value: "r1d1m2", label: "R1D1M2 Jamu" },
  { value: "r1d1m3", label: "R1D1M3 Adhi" },
  { value: "r1d1m4", label: "R1D1M4 Jobber" },
  { value: "r1d1m5", label: "R1D1M5 Radler" }
];

const villages = [
  { value: "r1d1m1v1", label: "R1D1M1V1 Rachla" },
  { value: "r1d1m1v2", label: "R1D1M1v2 Darbu" },
  { value: "r1d1m1v3", label: "R1D1M1V3 Agdo" },
  { value: "r1d1m1v4", label: "R1D1M1V4 Nonteng North" }
];

const confirms = [{ value: "1", label: "Municipality" }];

const insurees = [
  {
    chid: "172389HK9",
    lastName: "Brook",
    givenName: "James",
    gender: "Male",
    birthDate: "05/03/1997",
    beneficiaryCard: false
  },
  {
    chid: "7892389HK",
    lastName: "Brook",
    givenName: "Elisabeth",
    gender: "Female",
    birthDate: "12/02/1999",
    beneficiaryCard: false
  }
];
const insureesHeaders = [
  "Insurance Number",
  "Last Name",
  "Given Name",
  "Gender",
  "Birth Date",
  "Beneficiary Card",
  ""
];
const insureesItemFormatters = [
  (i, idx) => i.chid,
  (i, idx) => i.lastName,
  (i, idx) => i.givenName,
  (i, idx) => i.gender,
  (i, idx) => i.birthDate,
  (i, idx) => <Checkbox color="primary" disabled={true} />,
  (i, idx) => (
    <IconButton>
      <DeleteIcon />
    </IconButton>
  )
];

const insureesAligns = [null, null, null, null, null, null, "right"];

const policies = [
  {
    enrollmentDate: "19/05/2020",
    effectiveDate: "19/05/2020",
    startDate: "19/05/2020",
    expiryDate: "19/05/2020",
    product: "BCUL0001",
    enrollmentOfficer: "JH001 Jony Tanu",
    policyStatus: "Active",
    policyValue: "10,000.00",
    validFrom: "19/05/2020",
    validTo: null
  }
];
const policiesHeaders = [
  "Enrolment Date",
  "Effective Date",
  "Start Date",
  "Expiry Date",
  "Product",
  "Enrolment Officer",
  "Policy Status",
  "Policy Value",
  "Valid From",
  "Valid To",
  ""
];
const policiesItemFormatters = [
  (i, idx) => i.enrollmentDate,
  (i, idx) => i.effectiveDate,
  (i, idx) => i.startDate,
  (i, idx) => i.expiryDate,
  (i, idx) => i.product,
  (i, idx) => i.enrollmentOfficer,
  (i, idx) => i.policyStatus,
  (i, idx) => i.policyValue,
  (i, idx) => i.validFrom,
  (i, idx) => i.validTo,
  (i, idx) => (
    <IconButton>
      <DeleteIcon />
    </IconButton>
  )
];
const policiesAligns = [
  null,
  null,
  null,
  null,
  null,
  null,
  null,
  null,
  null,
  null,
  "right"
];

const contributions = [
  {
    paymentDate: "19/05/2020",
    payer: "Coffee Farmers Association",
    amount: "10,000.00",
    paymentType: "Cash",
    receipt: "331333",
    contributionCat: "Contribution"
  }
];
const contributionsHeaders = [
  "Payment Date",
  "Payer",
  "Amount",
  "Payment Type",
  "Receipt N°",
  "Contribution Category",
  ""
];
const contributionsItemFormatters = [
  (i, idx) => i.paymentDate,
  (i, idx) => i.payer,
  (i, idx) => i.amount,
  (i, idx) => i.paymentType,
  (i, idx) => i.receipt,
  (i, idx) => i.contributionCat,
  (i, idx) => (
    <IconButton>
      <DeleteIcon />
    </IconButton>
  )
];
const contributionsAligns = [null, null, null, null, null, null, "right"];

class RDLocation extends Component {
  render() {
    const { classes, ro = false, x = 1 } = this.props;

    return (
      <Fragment>
        <Grid item xs={3 * x} className={classes.item}>
          <FormControl required={true} fullWidth>
            <InputLabel className={classes.label}>Region</InputLabel>
            <Select value="r1" readOnly={ro}>
              {regions.map((option, idx) => (
                <MenuItem value={option.value}>{option.label}</MenuItem>
              ))}
            </Select>
          </FormControl>
        </Grid>
        <Grid item xs={3 * x}>
          <FormControl required={true} fullWidth>
            <InputLabel className={classes.label}>District</InputLabel>
            <Select value="r1d1" readOnly={ro}>
              {districts.map((option, idx) => (
                <MenuItem value={option.value}>{option.label}</MenuItem>
              ))}
            </Select>
          </FormControl>
        </Grid>
      </Fragment>
    );
  }
}

const StyledRDLocation = withTheme(withStyles(styles)(RDLocation));

class MVLocation extends Component {
  render() {
    const { classes, ro = false, x = 1 } = this.props;

    return (
      <Fragment>
        <Grid item xs={3 * x}>
          <FormControl required={true} fullWidth>
            <InputLabel className={classes.label}>Municipality</InputLabel>
            <Select value="r1d1m1" readOnly={ro}>
              {municipalities.map((option, idx) => (
                <MenuItem value={option.value}>{option.label}</MenuItem>
              ))}
            </Select>
          </FormControl>
        </Grid>
        <Grid item xs={3 * x}>
          <FormControl required={true} fullWidth>
            <InputLabel className={classes.label}>Village</InputLabel>
            <Select value="r1d1m1v1" readOnly={ro}>
              {villages.map((option, idx) => (
                <MenuItem value={option.value}>{option.label}</MenuItem>
              ))}
            </Select>
          </FormControl>
        </Grid>
      </Fragment>
    );
  }
}

const StyledMVLocation = withTheme(withStyles(styles)(MVLocation));

class FamilyMasterPanel extends Component {
  render() {
    const { classes } = this.props;

    return (
      <Fragment>
        <Typography className={classes.tableTitle}>
          Family/Group Details
        </Typography>
        <Divider />
        <Grid container spacing={3} className={classes.item}>
          <StyledRDLocation ro={true} />
          <StyledMVLocation ro={true} />
          <Grid item xs={3}>
            <TextField
              fullWidth
              required={true}
              disabled={true}
              label="Insurance Number"
              InputLabelProps={{
                className: classes.label
              }}
              value="333232333"
            />
          </Grid>
          <Grid item xs={3}>
            <TextField
              fullWidth
              label="Last Name"
              required={true}
              disabled={true}
              InputLabelProps={{
                className: classes.label
              }}
              value="Brook"
            />
          </Grid>
          <Grid item xs={3}>
            <TextField
              fullWidth
              label="Given Name"
              required={true}
              disabled={true}
              InputLabelProps={{
                className: classes.label
              }}
              value="James"
            />
          </Grid>
          <Grid item xs={3}>
            <FormControlLabel
              control={<Checkbox color="primary" disabled={true} />}
              label="Poverty Status"
            />
          </Grid>
          <Grid item xs={3}>
            <FormControl required={true} fullWidth>
              <InputLabel className={classes.label}>
                Confirmation Type
              </InputLabel>
              <Select disabled={true} value="1">
                {confirms.map((option, idx) => (
                  <MenuItem value={option.value}>{option.label}</MenuItem>
                ))}
              </Select>
            </FormControl>
          </Grid>
          <Grid item xs={3}>
            <TextField
              fullWidth
              label="Confirmation Number"
              required={true}
              disabled={true}
              InputLabelProps={{
                className: classes.label
              }}
              value="JLKA838947"
            />
          </Grid>
          <Grid item xs={6}>
            <TextField
              fullWidth
              multiline
              rows={2}
              label="Permanent Address Details"
              required={true}
              disabled={true}
              InputLabelProps={{
                className: classes.label
              }}
              value={`Street n°12\n73892 - Location`}
            />
          </Grid>
        </Grid>
      </Fragment>
    );
  }
}

const StyledFamilyMasterPanel = withTheme(
  withStyles(styles)(FamilyMasterPanel)
);

class TableMenu extends Component {
  render() {
    const { classes } = this.props;
    return (
      <Grid item className={classes.item}>
        <IconButton>
          <AddIcon />
        </IconButton>
      </Grid>
    );
  }
}

const StyledTableMenu = withTheme(withStyles(styles)(TableMenu));

class InsureesPanel extends Component {
  render() {
    const { classes } = this.props;

    return (
      <Paper className={classes.paper}>
        <Grid container>
          <Grid item xs={8} className={classes.paperHeaderTitle}>
            Insurees
          </Grid>
          <Grid item xs={4}>
            <Grid container direction="row" justify="flex-end">
              <StyledTableMenu />
            </Grid>
          </Grid>
          <Grid item xs={12} className={classes.paperDivider}>
            <Divider />
          </Grid>
          <Grid item xs={12}>
            <Table
              headers={insureesHeaders}
              itemFormatters={insureesItemFormatters}
              items={insurees}
              aligns={insureesAligns}
            />
          </Grid>
        </Grid>
      </Paper>
    );
  }
}

const StyledInsureesPanel = withTheme(withStyles(styles)(InsureesPanel));

class PoliciesPanel extends Component {
  render() {
    const { classes } = this.props;

    return (
      <Paper className={classes.paper}>
        <Grid container>
          <Grid item xs={8} className={classes.paperHeaderTitle}>
            Policies
          </Grid>
          <Grid item xs={4}>
            <Grid container direction="row" justify="flex-end">
              <StyledTableMenu />
            </Grid>
          </Grid>
          <Grid item xs={12} className={classes.paperDivider}>
            <Divider />
          </Grid>
          <Grid item xs={12}>
            <Table
              headers={policiesHeaders}
              itemFormatters={policiesItemFormatters}
              items={policies}
              aligns={policiesAligns}
            />
          </Grid>
        </Grid>
      </Paper>
    );
  }
}

const StyledPoliciesPanel = withTheme(withStyles(styles)(PoliciesPanel));

class ContributionsPanel extends Component {
  render() {
    const { classes } = this.props;

    return (
      <Paper className={classes.paper}>
        <Grid container>
          <Grid item xs={8} className={classes.paperHeaderTitle}>
            Contributions
          </Grid>
          <Grid item xs={4}>
            <Grid container direction="row" justify="flex-end">
              <StyledTableMenu />
            </Grid>
          </Grid>
          <Grid item xs={12} className={classes.paperDivider}>
            <Divider />
          </Grid>
          <Grid item xs={12}>
            <Table
              headers={contributionsHeaders}
              itemFormatters={contributionsItemFormatters}
              items={contributions}
              aligns={contributionsAligns}
            />
          </Grid>
        </Grid>
      </Paper>
    );
  }
}

const StyledContributionsPanel = withTheme(
  withStyles(styles)(ContributionsPanel)
);

class FamilyOverview extends Component {
  render() {
    return (
      <div>
        <Form
          HeadPanel={StyledFamilyMasterPanel}
          back={e => {}}
          title="Family/Group Overview"
          Panels={[
            StyledInsureesPanel,
            StyledPoliciesPanel,
            StyledContributionsPanel
          ]}
        />
      </div>
    );
  }
}

export default withTheme(withStyles(styles)(FamilyOverview));
